bayespy.inference.vmp.nodes.categorical.CategoricalDistribution.compute_moments_and_cgf
=======================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.categorical

.. automethod:: CategoricalDistribution.compute_moments_and_cgf